pub struct ConnectionHandler {
    pub config: CoreConfig,
    pub db_pool: Pool<PostgresConnectionManager<MakeTlsConnector>>,
    pub local_addr: SocketAddr,
    pub remote_addr: SocketAddr,
    pub tls_info: Option<TlsInfo>,
}
ConnectionHandler

A date type containing the hyper Request with the CoreConfig server statics, tls information, and postgres client db threadpool (Pool)

Core Config

CoreConfig for static configuration values

bb8 Threadpool

bb8 thread pool (Pool) containing a PostgresConnectionManager client that encrypts the traffic with a MakeTlsConnector for db client tls encryption

Socket Data

local_addr - server address remote_addr - client address

TLS Info

TlsInfo object for tls verification (this is not optional with the default configuration).

Fields

config: CoreConfigdb_pool: Pool<PostgresConnectionManager<MakeTlsConnector>>local_addr: SocketAddrremote_addr: SocketAddrtls_info: Option<TlsInfo>